From 72ec36a6bb382946be672fc1601db0363e7fc9a8 Mon Sep 17 00:00:00 2001
From: Jake Taylor <jake@elixxir.io>
Date: Thu, 23 Jun 2022 12:24:33 -0500
Subject: [PATCH] update restlike readme

---
 bindings/cmix.go   | 2 +-
 cmd/root.go        | 2 +-
 restlike/README.md | 4 ++--
 xxdk/cmix.go       | 8 ++++----
 xxdk/utils_test.go | 2 +-
 5 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/bindings/cmix.go b/bindings/cmix.go
index 432116eac..2003f7c2f 100644
--- a/bindings/cmix.go
+++ b/bindings/cmix.go
@@ -34,7 +34,7 @@ type Cmix struct {
 //
 // Users of this function should delete the storage directory on error.
 func NewKeystore(network, storageDir string, password []byte, regCode string) error {
-	if err := xxdk.NewClient(network, storageDir, password, regCode); err != nil {
+	if err := xxdk.NewCmix(network, storageDir, password, regCode); err != nil {
 		return errors.New(fmt.Sprintf("Failed to create new client: %+v",
 			err))
 	}
diff --git a/cmd/root.go b/cmd/root.go
index bd49ab29c..d9373fe1a 100644
--- a/cmd/root.go
+++ b/cmd/root.go
@@ -597,7 +597,7 @@ func createClient() *xxdk.Cmix {
 			}
 
 		} else {
-			err = xxdk.NewClient(string(ndfJSON), storeDir,
+			err = xxdk.NewCmix(string(ndfJSON), storeDir,
 				pass, regCode)
 		}
 
diff --git a/restlike/README.md b/restlike/README.md
index f4c117e73..2e09682c0 100644
--- a/restlike/README.md
+++ b/restlike/README.md
@@ -18,11 +18,11 @@ ndfJson, err := xxdk.DownloadAndVerifySignedNdfWithUrl(url, cert)
 Example:
 
 ```go
-err := xxdk.NewClient(ndfJson, "/clientStorage", []byte("testPassword"), "")
+err := xxdk.NewCmix(ndfJson, "/clientStorage", []byte("testPassword"), "")
 ```
 
 3. LoadCmix in order to obtain the xxdk.Cmix object.
-   `storageDir` and `password` may be customized, but must match the values provided to `NewClient()`.
+   `storageDir` and `password` may be customized, but must match the values provided to `NewCmix()`.
    The result of `xxdk.GetDefaultParams()` may also be freely modified according to your needs.
 
 Example:
diff --git a/xxdk/utils_test.go b/xxdk/utils_test.go
index 2f6afc719..e537fc3b9 100644
--- a/xxdk/utils_test.go
+++ b/xxdk/utils_test.go
@@ -39,7 +39,7 @@ func newTestingClient(face interface{}) (*Cmix, error) {
 	marshalledDef, _ := def.Marshal()
 	storageDir := "ignore.1"
 	password := []byte("hunter2")
-	err := NewClient(string(marshalledDef), storageDir, password, "AAAA")
+	err := NewCmix(string(marshalledDef), storageDir, password, "AAAA")
 	if err != nil {
 		return nil, errors.Errorf(
 			"Could not construct a mock client: %v", err)
diff --git a/xxdk/cmix.go b/xxdk/cmix.go
index ee7d46949..e8aaed282 100644
--- a/xxdk/cmix.go
+++ b/xxdk/cmix.go
@@ -61,13 +61,13 @@ type Cmix struct {
 	events *event.Manager
 }
 
 // NewClient creates client storage, generates keys, connects, and registers
 // with the network. Note that this does not register a username/identity, but
 // merely creates a new cryptographic identity for adding such information
 // at a later date.
-func NewClient(ndfJSON, storageDir string, password []byte,
+func NewCmix(ndfJSON, storageDir string, password []byte,
 	registrationCode string) error {
-	jww.INFO.Printf("NewClient(dir: %s)", storageDir)
+	jww.INFO.Printf("NewCmix(dir: %s)", storageDir)
 	rngStreamGen := fastRNG.NewStreamGenerator(12, 1024,
 		csprng.NewSystemRNG)
 
@@ -566,7 +566,7 @@ func DecodeGroups(ndf *ndf.NetworkDefinition) (cmixGrp, e2eGrp *cyclic.Group) {
 	return cmixGrp, e2eGrp
 }
 
 // CheckVersionAndSetupStorage is common code shared by NewClient,
 // NewPrecannedClient and NewVanityClient it checks client version and
 // creates a new storage for user data
 func CheckVersionAndSetupStorage(def *ndf.NetworkDefinition,
@@ -61,13 +61,13 @@ type Cmix struct {
 }
 
-// NewClient creates client storage, generates keys, connects, and registers
+// NewCmix creates client storage, generates keys, connects, and registers
 // with the network. Note that this does not register a username/identity, but
 // merely creates a new cryptographic identity for adding such information
@@ -566,7 +566,7 @@ func DecodeGroups(ndf *ndf.NetworkDefinition) (cmixGrp, e2eGrp *cyclic.Group) {
 }
 
-// CheckVersionAndSetupStorage is common code shared by NewClient,
+// CheckVersionAndSetupStorage is common code shared by NewCmix,
 // NewPrecannedClient and NewVanityClient it checks client version and
 // creates a new storage for user data
-- 
GitLab